@@ -525,7 +525,7 @@ unsigned long update_free(DOS_FS *fs)
 
     if (verbose)
 	printf("Checking free cluster summary.\n");
-    if (fs->free_clusters >= 0) {
+    if (fs->free_clusters != 0xFFFFFFFF) {
 	if (free != fs->free_clusters) {
 	    printf( "Free cluster summary wrong (%ld vs. really %ld)\n",
 		    fs->free_clusters,free);
@@ -538,11 +538,13 @@ unsigned long update_free(DOS_FS *fs)
     }
     else {
 	printf( "Free cluster summary uninitialized (should be %ld)\n", free );
-	if (interactive)
-	    printf( "1) Set it\n2) Leave it uninitialized\n" );
-	else printf( "  Auto-setting.\n" );
-	if (!interactive || get_key("12","?") == '1')
-	    do_set = 1;
+	if (rw) {
+	    if (interactive)
+	        printf( "1) Set it\n2) Leave it uninitialized\n" );
+	    else printf( "  Auto-setting.\n" );
+	    if (!interactive || get_key("12","?") == '1')
+	        do_set = 1;
+	}
     }
 
     if (do_set) {
@@ -554,7 +556,3 @@ unsigned long update_free(DOS_FS *fs)
 
     return free;
 }
-
-/* Local Variables: */
-/* tab-width: 8     */
-/* End:             */
